@@ -46,7 +46,7 @@ sub Output {
 
     my ($GRAMMAR, $TERMS, $FILENAME, $PACKAGES); # Cas
     my($package)=$self->Option('classname');
-    my($head,$states,$rules,$tail,$driver, $bypass, $accessors);
+    my($head,$states,$rules,$tail,$driver, $bypass, $accessors, $buildingtree);
     my($version)=$Parse::Eyapp::Driver::VERSION;
     my($datapos);
     my $makenodeclasses = '';
@@ -56,7 +56,7 @@ sub Output {
 #    This file was generated using Parse::Eyapp version <<$version>>.
 #
 # (c) Parse::Yapp Copyright 1998-2001 Francois Desarmenien.
-# (c) Parse::Eyapp Copyright 2006 Casiano Rodriguez-Leon. Universidad de La Laguna.
+# (c) Parse::Eyapp Copyright 2006-2007 Casiano Rodriguez-Leon. Universidad de La Laguna.
 #        Don't edit this file, use source file <<$FILENAME>> instead.
 #
 #             ANY CHANGE MADE HERE WILL BE LOST !
@@ -94,6 +94,7 @@ sub new {
 <<$rules>>,
 ################ @@@@@@@@@ End of User Code @@@@@@@@@ ###################
                                   yybypass => <<$bypass>>,
+                                  yybuildingtree => <<$buildingtree>>,
                                   @_,);
     bless($self,$class);
 
@@ -120,6 +121,7 @@ EOT
 
   ($GRAMMAR, $PACKAGES) = $self->Rules();
   $bypass = $self->Bypass;
+  $buildingtree = $self->Buildingtree;
   $accessors = $self->Accessors;
   $TERMS = $self->Terms();
   $FILENAME = '"'.$self->Option('inputfile').'"';
